==> haskell-data-accessor-template-0.2.1.12-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-data-accessor-template.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-accessor-template
version: 0.2.1.12
id: data-accessor-template-0.2.1.12-3y3Zsv9U5bH1jCHSkfn9BW
key: data-accessor-template-0.2.1.12-3y3Zsv9U5bH1jCHSkfn9BW
license: BSD3
maintainer: Henning Thielemann <haskell@henning-thielemann.de>
homepage: http://www.haskell.org/haskellwiki/Record_access
synopsis: Utilities for accessing and manipulating fields of records
description:
    Automate generation of @Accessor@'\''s of the @data-accessor@ package
    by Template Haskell functions.
category: Data
author: Luke Palmer <lrpalmer@gmail.com>,
        Henning Thielemann <haskell@henning-thielemann.de>
exposed: True
exposed-modules:
    Data.Accessor.Template
hidden-modules: Data.Accessor.Template.Example
abi: 6a28b27975de41b6519cc233d19cef8d
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/data-accessor-template-0.2.1.12
library-dirs: /usr/lib/ghc-8.0.1/site-local/data-accessor-template-0.2.1.12
data-dir: /usr/share/arm-linux-ghc-8.0.1/data-accessor-template-0.2.1.12
hs-libraries: HSdata-accessor-template-0.2.1.12-3y3Zsv9U5bH1jCHSkfn9BW
depends:
    base-4.9.0.0 data-accessor-0.2.2.7-8YIdFyGw7Iv38wc1N9wMCB
    template-haskell-2.11.0.0 utility-ht-0.0.11-BVpr5tWJXMj5StSkdnqVlq
haddock-interfaces: /usr/share/doc/haskell-data-accessor-template/html/data-accessor-template.haddock
haddock-html: /usr/share/doc/haskell-data-accessor-template/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-accessor-template-0.2.1.13-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-data-accessor-template.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-accessor-template
version: 0.2.1.13
id: data-accessor-template-0.2.1.13-5jMSJRZnKAvDeLF7YefEeS
key: data-accessor-template-0.2.1.13-5jMSJRZnKAvDeLF7YefEeS
license: BSD3
maintainer: Henning Thielemann <haskell@henning-thielemann.de>
homepage: http://www.haskell.org/haskellwiki/Record_access
synopsis: Utilities for accessing and manipulating fields of records
description:
    Automate generation of @Accessor@'\''s of the @data-accessor@ package
    by Template Haskell functions.
category: Data
author: Luke Palmer <lrpalmer@gmail.com>,
        Henning Thielemann <haskell@henning-thielemann.de>
exposed: True
exposed-modules:
    Data.Accessor.Template
hidden-modules: Data.Accessor.Template.Example
abi: d0cfe96acb2500cca84c2d7963a11b96
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/data-accessor-template-0.2.1.13
library-dirs: /usr/lib/ghc-8.0.1/site-local/data-accessor-template-0.2.1.13
data-dir: /usr/share/arm-linux-ghc-8.0.1/data-accessor-template-0.2.1.13
hs-libraries: HSdata-accessor-template-0.2.1.13-5jMSJRZnKAvDeLF7YefEeS
depends:
    base-4.9.0.0 data-accessor-0.2.2.7-8YIdFyGw7Iv38wc1N9wMCB
    template-haskell-2.11.0.0 utility-ht-0.0.11-BVpr5tWJXMj5StSkdnqVlq
haddock-interfaces: /usr/share/doc/haskell-data-accessor-template/html/data-accessor-template.haddock
haddock-html: /usr/share/doc/haskell-data-accessor-template/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
